covariate_pred: covariate prediction

View source: R/unsae.r

covariate_predR Documentation

covariate prediction

Description

to calculate the spatial random effect for a new data set.

Usage

covariate_pred(em_output, test_set)

Arguments

em_output

the outcome from the multilevel_EM function.

test_set

the test set (or new data set). The data set *should* have the predictor columns as well as the coordinate columns, all with the same names with the training data set.

Value

predicted covariates parts Xb at new data set


ydhwang/unsae documentation built on May 4, 2023, 7:24 p.m.