multilevel_EM: multilevel EM

View source: R/unsae.r

multilevel_EMR Documentation

multilevel EM

Description

a main function to fit multilevel em with gaussian spatial correlation. Some chunk of the code has been dedicated to handle the syntax. glmer function is called to get the initial value of the estimates.

Usage

multilevel_EM(formula, data, tol = 0.001, coordinates)

Arguments

formula

formula argument following the glmer syntax.

data

name of the data set.

tol

tolerence level to control the em convergence. default value 1e-3.

coordinates

specifying the name of coordinates within the data. These columns *should* exist within the data set provided.

Value

list of element that are needed for the prediction.


ydhwang/unsae documentation built on May 4, 2023, 7:24 p.m.