predict_em: main prediction

View source: R/unsae.r

predict_emR Documentation

main prediction

Description

a wrapper to calculate the spatial random effect for a new data set.

Usage

predict_em(em_output, test_set)

Arguments

em_output

the outcome from the multilevel_EM function.

test_set

the test set (or new data set). The data set *should* have the predictor columns as well as the coordinate columns, all with the same names with the training data set.

Value

predicted outcome combining covariates parts Xb and spatial random effects at new data set


ydhwang/unsae documentation built on May 4, 2023, 7:24 p.m.