spatial_pred: spatial prediction

View source: R/unsae.r

spatial_predR Documentation

spatial prediction

Description

to calculate the spatial random effect for a new data set.

Usage

spatial_pred(em_output, test_set)

Arguments

em_output

the outcome from the multilevel_EM function.

test_set

the test set (or new data set). The data set *should* have the predictor columns as well as the coordinate columns, all with the same names with the training data set.

Value

predicted spatial random effect at new data set


ydhwang/unsae documentation built on May 4, 2023, 7:24 p.m.