| multilevel_EM | R Documentation |
a main function to fit multilevel em with gaussian spatial correlation. Some chunk of the code has been dedicated to handle the syntax. glmer function is called to get the initial value of the estimates.
multilevel_EM(formula, data, tol = 0.001, coordinates)
formula |
formula argument following the glmer syntax. |
data |
name of the data set. |
tol |
tolerence level to control the em convergence. default value 1e-3. |
coordinates |
specifying the name of coordinates within the data. These columns *should* exist within the data set provided. |
list of element that are needed for the prediction.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.