| predict_em | R Documentation |
a wrapper to calculate the spatial random effect for a new data set.
predict_em(em_output, test_set)
em_output |
the outcome from the multilevel_EM function. |
test_set |
the test set (or new data set). The data set *should* have the predictor columns as well as the coordinate columns, all with the same names with the training data set. |
predicted outcome combining covariates parts Xb and spatial random effects at new data set
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.